Rank enum

Represents the rank (face value) of a playing card.

Inheritance
Available extensions

Values

ace → const Rank
const Rank('A', 1)
two → const Rank
const Rank('2', 2)
three → const Rank
const Rank('3', 3)
four → const Rank
const Rank('4', 4)
five → const Rank
const Rank('5', 5)
six → const Rank
const Rank('6', 6)
seven → const Rank
const Rank('7', 7)
eight → const Rank
const Rank('8', 8)
nine → const Rank
const Rank('9', 9)
ten → const Rank
const Rank('10', 10)
jack → const Rank
const Rank('J', 11)
queen → const Rank
const Rank('Q', 12)
king → const Rank
const Rank('K', 13)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
The display symbol of the rank.
final
value int
The numeric value of the rank (Ace = 1, Jack = 11, Queen = 12, King = 13).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Rank>
A constant List of the values in this enum, in order of their declaration.