ShuffleAlgorithm enum
Defines the algorithm used to shuffle a deck of cards.
Values
- fisherYates → const ShuffleAlgorithm
-
Fisher-Yates (Knuth) shuffle — uniform random distribution.
- riffle → const ShuffleAlgorithm
-
Riffle shuffle — simulates a real-world bridge/riffle shuffle.
- overhand → const ShuffleAlgorithm
-
Overhand shuffle — simulates an overhand (cut-and-stack) shuffle.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ShuffleAlgorithm> - A constant List of the values in this enum, in order of their declaration.